#!/bin/sh -eu

FILE="$DEST/altinst/usr/share/install2/postinstall.d/08-nfslock-on.sh"

echo "Injecting nfslock enabler..."

cat > "$FILE" << EOF
#!/bin/sh -efu

. install2-init-functions

chroot \$destdir chkconfig nfslock on
EOF

chmod 755 "$FILE"

echo "Done."

