#!/bin/sh -eu

DIR="$DEST/altinst/usr/share/install2/preinstall.d"

echo "Injecting mktemp enabler..."

sed -i 's/disabled/enabled/g' "$DIR/45-mktemp-disable"
mv "$DIR/45-mktemp-disable" "$DIR/45-mktemp-enable"

echo "Done."

