((workstation
  (title . "Setup for workstation")
  (action . trivial)
  (actiondata  ("swap" (size 1048576 . 2097152) (fsim . "SWAPFS") (methods plain))
               ("/" (size 4194304 . #t) (fsim . "Ext2/3") (methods  plain))))
 (server
  (title . "Setup for server")
  (action . trivial)
  (actiondata ("swap" (size 1048576 . 2097152) (fsim . "SWAPFS") (methods raid plain))
              ("/" (size . 1048576) (fsim . "Ext2/3") (methods raid plain))
              ("/usr" (size . 4194304) (fsim . "Ext2/3") (methods raid plain))
              ("/home" (size . 2097152) (fsim . "Ext2/3") (methods raid plain))
              ("/var" (size 4194304 . #t) (fsim . "XFS") (methods raid plain)))))
