(("syslang") language ("ru_RU") action "write" lang ("ru_RU"))
(("sysfont") language ("ru_RU") action "write")
(("syskbd" "alt_sh_toggle") language ("ru_RU") action "write")
(("evms" "control") language ("en_US") action "write" control open installer #t)
(("evms" "control") language ("en_US") action "write" control update)
(("evms" "profiles" "workstation") language ("en_US") action apply commit #t clearall #t exclude ())
(("evms" "control") language ("en_US") action "write" control commit)
(("evms" "control") language ("en_US") action "write" control close)
(("basesystem") language ("ru_RU") action "write")
(("preinstall") language ("ru_RU") action "write")
(("deadline") language ("ru_RU") action "write")
(("lilo") language ("ru_RU") action "write" target "boot" devname "hda")
(("lilo") action "constraints" orig_action "write" language ("ru_RU") target "globals" boot "hda" map "/boot/map" append "resume=/dev/hda1 panic=30" timeout "100" install "menu" extraboot "" password1 "pass1word" password2 "pass1word" method "restricted" confonly #f)
(("lilo") action "write" language ("ru_RU") target "globals" boot "hda" map "/boot/map" append "resume=/dev/hda1 panic=30" timeout "100" install "menu" extraboot "" password1 "pass1word" password2 "pass1word" method "restricted" confonly #f)
(("lilo") language ("ru_RU") action "commit")
(("pkg-update") language ("ru_RU") action "write")
(("root") language ("ru_RU") action "write" passwd1 "root" passwd2 "root")
(("users") language ("ru_RU") action "new" name "guest" allow_su #t passwd1 "guest" passwd2 "guest")
(("net-general") language ("ru_RU") action "write" hostname_auto #t dns_auto #t hostname "localhost.localdomain" dns "10.0.2.3" search "class.altlinux.ru" restart #f)
(("net-eth" "eth0") action "constraints" orig_action "write" language ("ru_RU") dhcp #t ip "" mask "24" hw_binding "mac" default "" restart #f)
(("net-eth" "eth0") action "write" language ("ru_RU") dhcp #t ip "" mask "24" hw_binding "mac" default "" restart #f)
(("x11") language ("ru_RU") action "write" commit #t monitor "Monitor 1024x768" xdepth "16" xresolution "640x480,720x576,800x600,832x624,848x480,960x720,1024x600,1024x736,1024x768" onboot #t)
