#!/bin/sh -eu

FILE="$DEST/altinst/usr/share/install2/postinstall.d/08-add-nfs-fstab.sh"

echo "Injecting fstab modification script..."

cat > "$FILE" << EOF
#!/bin/sh -efu

. install2-init-functions

echo "$SERVER:$NFS_HOME	/home	nfs	hard,intr,nosuid,nodev" >> \$destdir/etc/fstab
echo "$SERVER:$DEST	/mnt/disk	nfs	hard,intr,nosuid,nodev" >> \$destdir/etc/fstab
EOF

chmod 755 "$FILE"

echo "Done."

